@@ -1,3 +1,3 @@
 from marshmallow.validate import *
 
-from not_blank import not_blank
+from .not_blank import not_blank
